## 2020-科技新聞
### TechOrange 科技報橘
### TechOrange 科技報橘 電動車秘史：190 年前就已經上路，市占率還一度超過三成
| VIEW MORE »
|  | ### TechOrange 科技報橘 員工要在辦公室還是家裡，才更有生產力？微軟發表「混合辦公」最新趨勢觀察
| VIEW MORE »
### TechOrange 科技報橘 AI 可能會讓工程師失業，為什麼工程師還那麼愛？
| VIEW MORE »
|  | ### TechOrange 科技報橘 蘋果製造 Apple Car，是只做軟體還是會開發全車？
| VIEW MORE »
### TechOrange 科技報橘 隱形斗篷真的做得出來？超商常見的氣泡水，藏著隱形材料的秘密
| VIEW MORE »
|  | ### TechOrange 科技報橘 不用滑手機，眼睛看到就能發 IG 限動！臉書攜雷朋打造智慧眼鏡
| VIEW MORE »
### TechOrange 科技報橘 性愛可以緩解鼻塞！盤點 8 個 2021 搞笑諾貝爾獎冷知識
| VIEW MORE »
|  | ### TechOrange 科技報橘 一張信用卡玩出多種用法！國泰世華如何用網銀 App 玩出個人化數位金融新體驗
| VIEW MORE »
### iThome
### iThome Amazon進入電視機領域，推出Fire TV系列智慧電視
| VIEW MORE »
|  | ### iThome AI趨勢周報第176期：Uber數百PB資料分析全靠開源平臺，如何思考省錢戰略？
| VIEW MORE »
### iThome 國安局今年上半遭到逾3萬次攻擊，直逼去年總和
| VIEW MORE »
|  | ### iThome Coinbase的加密貨幣借貸服務收到SEC的提告通知
| VIEW MORE »
### iThome 因應橫跨25國業務拓展需求，宏碁歐洲總部搬遷3大核心系統上公有雲，目標取代兩座歐洲自有資料中心
| VIEW MORE »
|  | ### iThome 微軟發表全新個人化新聞服務Microsoft Start
| VIEW MORE »
### iThome Google推出2款Meet商用裝置
| VIEW MORE »
|  | ### iThome 勒索軟體REvil於暗網中再現蹤跡
| VIEW MORE »
### iThome Azure推按需容量預留功能，可保證預留虛擬機器運算能力
| VIEW MORE »
|  | ### iThome 薩爾瓦多成為全球第一個接納比特幣為法定貨幣的國家
| VIEW MORE »
### iThome 微軟加入開源雲平臺組織OpenInfra基金會
| VIEW MORE »
|  | ### iThome 從感知器到神經網路
| VIEW MORE »
### iThome 工研院與Arm聯手，為新創業者引進Arm IP打造IC設計平臺
| VIEW MORE »
|  | ### iThome 蘋果Apple Watch主管接手自駕車開發專案部門
| VIEW MORE »
### iThome 紐時：開挖比特幣所使用的電力是Google總用電量的7倍
| VIEW MORE »
|  | ### iThome Cloud周報第120期：多月前部署工作出包讓AWS東京區域近期斷網6小時，波及SBI證券、NTT Docomo等多家大型企業網路服務
| VIEW MORE »
### iThome Google以深度學習偵測異常胸腔X光片，可找出訓練資料集未見過的肺部異常
| VIEW MORE »
|  | ### iThome 臉書發表Ray-Ban Stories智慧眼鏡
| VIEW MORE »
### iThome Databricks發布Serverless SQL，用戶不須管理伺服器即時獲得SQL運算能力
| VIEW MORE »
|  | ### iThome 紐西蘭郵政總局、銀行遭DDoS攻擊
| VIEW MORE »
### iThome 報導：德國政府曾向NSO購買Pegasus間諜軟體
| VIEW MORE »
|  | ### iThome IoT雙周報第99期：無人叫車服務將屆滿一年，Waymo自駕車終於駛入舊金山市區
| VIEW MORE »
### iThome 研究人員：Windows最新MSHTML漏洞比想像中危險
| VIEW MORE »
|  | ### iThome MITRE Engage將取代MITRE Shield，聚焦交戰、拒絕與欺敵領域
| VIEW MORE »
### iThome 蘋果宣布要在9月14日舉行虛擬發表會
| VIEW MORE »
|  | ### iThome 2022英特爾基礎設施處理器：Mount Evans
| VIEW MORE »
### iThome 五倍券10/8起開放使用，因應防疫、轉型需要，政府力推數位券
| VIEW MORE »
|  | ### iThome 2022英特爾伺服器平臺：Sapphire Rapids
| VIEW MORE »
### iThome Canonical推輕量Anbox Cloud，可安裝至單個AWS執行個體
| VIEW MORE »
|  | ### iThome 英特爾的處理器反攻
| VIEW MORE »
### iThome 2022 Intel運算架構大公開！
| VIEW MORE »
|  | ### iThome 程式碼執行漏洞促使Google Tensorflow中止支援YAML
| VIEW MORE »
### iThome Amazon 無人商店系統Just Walk Out將在Whole Foods超市測試
| VIEW MORE »
|  | ### iThome 推特開始測試社群功能，集結對相同主題感興趣的用戶
| VIEW MORE »
### iThome 報告：企業不當使用自動化聘僱系統，反誤擋了大量可能人才
| VIEW MORE »
|  | ### iThome 誠品新電商平臺開站後首度加入周年慶，打造線下快閃店實現虛實融合購物體驗
| VIEW MORE »
### iThome Spotify開源Python音效函式庫Pedalboard，供程式開發方法高速後製音訊
| VIEW MORE »
|  | ### iThome 微軟、AWS接手Google放棄的美國防部影像監控標案
| VIEW MORE »
### iThome 臉書開源快取引擎CacheLib，連結產業推動快取創新
| VIEW MORE »
|  | ### iThome 中國駭客APT41附屬組織利用Sidewalk後門發動攻擊，臺灣也有災情
| VIEW MORE »
### iThome VS Code Python擴充套件翻新測試介面，將棄用舊語言伺服器
| VIEW MORE »
|  | ### iThome AWS新服務合併量子電腦解決加密金鑰被破解的問題
| VIEW MORE »
### iThome 蘋果抓漏專案風評差：封閉、付款慢、修補也慢
| VIEW MORE »
|  | ### iThome 福特汽車挖走了蘋果的汽車主管Doug Field
| VIEW MORE »
### iThome 微軟併購網頁影片編輯器Clipchamp，補充Microsoft 365產品組合
| VIEW MORE »
|  | ### iThome 衛福部近日示警，當心假冒其名義的釣魚郵件
| VIEW MORE »
### iThome Windows RCE漏洞已有鎖定Office用戶的攻擊，微軟緊急提供緩解指示
| VIEW MORE »
|  | ### iThome OpenSSL 3.0加入新的FIPS模組，並棄用大量API
| VIEW MORE »
### iThome IT扮演藝文產業紓困方案推手，文化部力推文化科技加速轉型
| VIEW MORE »
|  | ### iThome 今年9月金融業設置資安長成為法律明文規定，擴及38家本土銀行之餘，符合條件的保險與證期業也須遵循
| VIEW MORE »
### iThome 藍牙耳機可能讓使用者被人追蹤
| VIEW MORE »
|  | ### iThome 2022英特爾資料中心繪圖處理器：Ponte Vecchio
| VIEW MORE »
### iThome 資安一周第162期：為落實個資保護監管責任及跨機關協調，行政院建立個資保護執行聯繫機制
| VIEW MORE »
|  | ### iThome AWS發布PyTorch用S3擴充套件，讓用戶直接串流S3資料訓練模型
| VIEW MORE »
### iThome 微軟修補可在Azure上接管他人容器的Azurescape漏洞
| VIEW MORE »
|  | ### iThome 隱私郵件服務ProtonMail將用戶IP位址交給警方掀風波
| VIEW MORE »
### iThome 駭客公布50萬組Fortinet VPN用戶帳號與密碼，74個國家受影響，臺灣第二嚴重
| VIEW MORE »
|  | ### iThome 微軟稱新常態，無限期延後員工返回公司上班時程
| VIEW MORE »
### iThome Jenkins已棄用的Confluence伺服器遭駭，Jenkins主程式、外掛軟體、程式碼皆不受影響
| VIEW MORE »
|  | ### iThome 印尼防疫網站未做好資料庫防護，導致百萬民眾資料外洩
| VIEW MORE »
### Business Next
### Business Next 蘋果設計走下「神」壇，走進直線時代、更人性化了？
| VIEW MORE »
|  | ### Business Next 退貨率僅1%、比iPhone還低！台灣最大生鮮電商，如何拚出年營收12億元？
| VIEW MORE »
### Business Next 老是犯同種錯誤！初階工程師如何對自己的程式碼負責？
| VIEW MORE »
|  | ### Business Next 群創搶人才！預約2022年碩博畢業生，祭10萬元早鳥簽約金、60萬獎學金
| VIEW MORE »
### Business Next 群電裁撤動力機械部門、資遣80人！同業：製造太集中中國
| VIEW MORE »
|  | ### Business Next 全球晶片供不應求、造價高昂，恐將拖延科技創新腳步
| VIEW MORE »
### Business Next P&G塞港、訂單爆量都不怕！快消品巨頭如何躲過停工、斷貨危機，銷售漲幅刷新高？
| VIEW MORE »
|  | ### Business Next 15家金控前8月獲利飆破4500億元！富邦金控寫下3驚奇、國泰金居次
| VIEW MORE »
### Business Next 低調現身報平安？馬雲4個月來首度亮相，視察集團菜棚
| VIEW MORE »
|  | ### Business Next 強颱璨樹陸上颱風警報發布、居家辦公仍要上班！5大追蹤平台一次看
| VIEW MORE »
### Business Next 好喝的「午後紅茶」竟是檢驗胰臟癌新秘方！日本研究：照超音波很有幫助
| VIEW MORE »
|  | ### Business Next 日本麥當勞最老店員！93歲老翁樂上一週4天夜班
| VIEW MORE »
### Business Next 騰訊、網易等遊戲巨頭被約談！中國要求執行未成年禁令，新遊戲也傳凍結批審
| VIEW MORE »
|  | ### Business Next 教學攝影機打進全美8萬所K12校園！台灣松下第3代掌門人，跨界瞄準「分享」生意
| VIEW MORE »
### Business Next 農遊券888元首波發給88萬人，消費滿千再抽第二波！與振興五倍券整合同一平台
| VIEW MORE »
|  | ### Business Next 藝FUN券面額600元要來了！數位券佔8成，總計300萬份
| VIEW MORE »
### Business Next 華碩神投資！擔任研華第2大股東15年、首度申讓7500張股票！獲利估逾20億元
| VIEW MORE »
|  | ### Business Next 豐田社長批日政府能源政策：只一味模仿歐洲，上百萬人恐失業！
| VIEW MORE »
### Business Next 生醫產發條例再延10年！CDMO、再生、精準醫療納獎勵，林全批：鼓勵生產方式而非技術將扭曲產業
| VIEW MORE »
|  | ### Business Next 蘋果、特斯拉也撐不住？晶片短缺潮，再大的公司也難逃
| VIEW MORE »
### Business Next 鮮乳坊從募資專案賣進大苑子、路易莎，竟始於一場公平交易的抗爭？
| VIEW MORE »
|  | ### Business Next 【簡立峰專欄】Low-Code / No-Code時代來臨，寫程式還是人才標配嗎？
| VIEW MORE »
### Business Next Dyson打了一個史上最貴的水漂？花超過200億元，造了輛自己都嫌貴的電動車
| VIEW MORE »
|  | ### Business Next 台灣味再消退！17LIVE將全球營運總部遷至日本，推新LOGO迎接品牌重塑
| VIEW MORE »
### Business Next 被美國醫院天價收費嚇到！YouTuber竟回家自製X光機自己拍？
| VIEW MORE »
|  | ### Business Next Apple Car高層跳槽福特後，傳Apple Watch軟體主管接手！曾透露造車玄機
| VIEW MORE »
### Business Next 一卡通推「BROWN & FRIENDS」熊大、兔兔及莎莉3D立體角色卡
| VIEW MORE »
|  | ### Business Next 從新創到石油巨頭都不敢錯過， 電動車浪潮點燃「充電大戰」
| VIEW MORE »
### Business Next 繼Roblox之後，Rec Room何以成為下一隻Metaverse獨角獸？
| VIEW MORE »
|  | ### Business Next 東元父子延長賽！鈺叡收購菱光不如預期，黃育仁掌握近3成股權
| VIEW MORE »
### Business Next 「缺什麼我就捐什麼」！台積電創新公益，張淑芬跑透全台只為捐太陽能發電站
| VIEW MORE »
|  | ### Business Next 從披薩小弟到健身服飾品牌CEO！GYMSHARK創辦人如何7年打造市值10億英鎊企業？
| VIEW MORE »
### Business Next 朕不給的你不能要！ 談談社群小編苦惱的觸及率
| VIEW MORE »
|  | ### Business Next Facebook智慧眼鏡Ray-Ban Stories亮相！攜手雷朋，外型時尚還可拍照聽音樂
| VIEW MORE »
### Business Next 五倍券如何變十倍？各家銀行大推數位綁定優惠，攻略懶人包一次看
| VIEW MORE »
|  | ### Business Next 最差的劇本卻放出盛大煙火！愛爾達靠奧運衝6倍訂閱數，接下來如何留住一日體育迷？
| VIEW MORE »
### Business Next 蘋果、PayPal都搶進戰局，「先買後付」如何把過客變顧客？
| VIEW MORE »
|  | ### Business Next 缺工潮蔓延，亞馬遜將為75萬名員工全額支付大學學費！為留才出了哪些招？
| VIEW MORE »
### INSIDE
### CTV 廣告結合傳統電視和數位廣告的優點，可視率、 VTR 完整觀看率大幅提升，更因為有數位廣告的技術，所以可以針對受眾做精準的廣告投放，同時也可以跨載具、再行銷。
| VIEW MORE »
### INSIDE 豐田表示，如果政府的環境目標、能源政策等不切實際，日本汽車產業 550 萬人很可能大半會失業。
| VIEW MORE »
|  | ### INSIDE 在可識別流量越來越少的情況下，可識別流量的 CPM 將會變得更昂貴。 Verizon Media 以獨家且多元的第一方數據，開發不同的解決方法來因應數位身份識別問題。
| VIEW MORE »
### INSIDE Inspiration4 是一項由美國億萬富翁、Shift4 Payment 的創辦人，同時有豐富飛機飛行經驗的 Jared Isaacman 所辦的太空計畫，也是首次全員平民上到地球軌道的計畫，以及首次上到地球軌道的私人商業太空旅程計畫。
| VIEW MORE »
|  | ### INSIDE 看不出帆船賽事的激烈競爭、無法第一時間看出小白球飛向何方⋯過去觀賞運動賽事的痛點，都在這次 2020 東京奧運迎刃而解，這背後關鍵轉捩點，正是 5G 商業應用！
| VIEW MORE »
### INSIDE 蘋果電動車的開發進展，似乎還有很長一段路要摸索前進，但如何面對市場跟投資人或許是第一道要煩惱的課題。
| VIEW MORE »
|  | ### INSIDE 臺灣中小製造業過去仰賴高度勞動力，數位韌性不足，運用雲服務工具可有效提升產能及效率，數位轉型同時也能協助企業創造市場競爭優勢。
| VIEW MORE »
### INSIDE 只要乘客上了車，我就覺得在手握方向盤的我好像消失了。
| VIEW MORE »
|  | ### INSIDE 地價稅認定上營業用房屋跟自住課稅金額差很大，財政部放寬認定，如果實際交易都是在網路平台上完成，且該營業登記的房屋，實際未供辦公、存放與營業活動相關的設備及物品，仍可適用自住用地稅率，。
| VIEW MORE »
### INSIDE 敏感字元包括「蔡英文」、「習近平」、「拜登」、「特朗普」（川普）等人名也被禁止用於創立角色。
| VIEW MORE »
|  | ### INSIDE 當感性的味覺遇上理性的分析，一瓶威士忌可以成為各種「數字」的總和，並在不同的味蕾上化作無法量化的感動。工程背景出身的陳建銘與邱德夫，一同走到了威士忌酒徒之路，以左腦的理性思維洞察好酒，牽動右腦無限創思。
| VIEW MORE »
### INSIDE 由夢想動畫提供的 LED 錐形投影技術，加上 Yahoo 的 AR 前景製作技術，呈現出「無懼行銷 2021 DSP Summit 」沉浸式研討會的絕佳視覺效果。
| VIEW MORE »
|  | ### INSIDE Facebook 亞太區新聞合作夥伴關係總監 Anjali Kapoor 在這篇文中，整理了三大關鍵，包括加速數位轉型，開創不同的營收來源，以及創造更多優質的新聞內容，一起來探討媒體業如何應對多變的未來。
| VIEW MORE »
### INSIDE 面對反覆無常的疫情，品牌要跟著消費者變化的腳步，善用精準行銷工具互動溝通。蝦皮 X Facebook 廣告可以達到更低的廣告購買成本、也有效開發新客。
| VIEW MORE »
|  | ### INSIDE 推特流傳文件指 Globalstar 獲 FCC授權，iPhone 13 支援衛星通訊功能的謠言又起激勵。
| VIEW MORE »
### INSIDE 17 LIVE 本次品牌重塑包括全球品牌名稱統一、全新企業 Logo、集團願景與品牌使命等。
| VIEW MORE »
|  | ### INSIDE 《超認真少年》頻道分享專業工業教學影片，讓更多人了解並尊重工業，顛覆大眾對做工的人刻板印象，專訪超級斜槓職人阿仔師。
| VIEW MORE »
### INSIDE 微軟於 8 月 10 日舉辦「DevDays Asia 2021 Online 亞太技術年會線上記者會」，透過「Reimagine Taiwan 臺灣產業新星座談分享」，邀請鉅鋼機械、網聯科技、康揚等夥伴分享在後疫時代所面臨的全新挑戰，以及如何透過微軟前瞻科技技術，打造新興應用、走向國際。
| VIEW MORE »
|  | ### INSIDE 也許最近有些人常聽到 Metaverse 或是「元宇宙」，不過這跟漫畫常出現的多元宇宙不一樣，而是常常在科幻作品裡面出現的虛擬世界。現在隨著科技進步、社群平台擴張，加上近年疫情與環境天災讓人們無法在實體見面，所以轉往線上滿足生活所需，這個數十年前仍只存在科幻作品的詞彙，也愈來愈接近實現的一天。
| VIEW MORE »
### INSIDE 蘇貞昌表示，五倍券實體券預計於 10 月 8 日國慶連假期間正式讓民眾領取。
| VIEW MORE »
|  | ### INSIDE 你想為孩子買一隻機器獨角獸嗎？
| VIEW MORE »
### INSIDE 麻省理工新創測試了一項全新的超導磁鐵，提升核融合技術發展零碳能源的機會。
| VIEW MORE »
|  | ### INSIDE 現在免費註冊 AWS 帳戶，不只可以享有上百種免費的雲端工具，參加線上 AWS 台灣雲端高峰會，還能與重量級講師一同實際操作演練
| VIEW MORE »
### INSIDE 豐田汽車計畫 2030 年之前將電池產能擴增至現行的逾 30 倍
| VIEW MORE »
|  | ### INSIDE 瑞士一間溫室氣體研究公司 Climeworks 把「二氧化碳」商業化，更獲得微軟的投資。
| VIEW MORE »
### INSIDE 擱置已久的博韋伯望遠鏡終於要在年底前往太空執行任務了嗎？這次的太空任務將由 NASA 與多家航空局攜手策劃。
| VIEW MORE »
|  | ### INSIDE 同時能結合眼鏡本身具備通話與聲音播放功能打造不同體驗。
| VIEW MORE »
### INSIDE 一場疫情，讓許多行業意識到「數位轉型，不轉不行」的危機，尤其是轉型腳步相對緩慢的製造業、零售流通業，在疫情當下更是受創嚴重的兩大業態。Google Cloud將在 9 月 29 日、9 月 30 日舉辦 Industry Summit Recap 線上研討會，主題多元豐富而且不用出門、不必花錢，究竟議程有多吸引人？
| VIEW MORE »
|  | ### INSIDE 官方承諾「一年保固」，如果買了 Roomba j7+ 一年內還是不小心「掃到」寵物大便，可免費更換一台。
| VIEW MORE »
### INSIDE Sony 在今年的 PlayStation Showcase 線上發表會，發佈多款熱門的遊戲大作新情報。
| VIEW MORE »
|  | ### INSIDE 疫情期間部份城市祭出費用上限規定，防止平台過度收費。
| VIEW MORE »
### INSIDE 成功大學高精地圖中心今天表示，全台高精地圖已建置約 120 公里，今年更推動建置自駕車用高精地圖 3 處驗證場域。
| VIEW MORE »
|  | ### INSIDE 世界先進預期今年全年都將維持相當高的產能利用率。
| VIEW MORE »
### INSIDE 從早期的靜態橫幅廣告到最近的創新廣告，數位行銷的創意設計已經走過一條漫長的道路，廣告主也必須隨之調整策略，因應快速演變的廣告格式，以取得與消費者保持緊密聯繫的機會。
| VIEW MORE »
|  | ### INSIDE 2020 東京奧運開幕式上，逾 1 千 8 百架無人機的升空，組成「地球」模樣照亮黑夜；一台台無人車駛進選手村，負責人員載送；再到台灣家戶中，使用 8K 畫質零時差地收看賽事⋯⋯這些創新科技的體驗深入生活，皆是 5G 應用的魔力！
| VIEW MORE »
### INSIDE 科普動畫「科學腦巨人」，這也是全台首部 4K 規格的腦科學 3D 動畫片，透過淺白的敘事讓觀眾探索腦部奧秘，預計 9 月 12 日晚上 6 時在公視 3 台首播。
| VIEW MORE »
|  | ### INSIDE 台達電子看見智造新力量，在遠傳 5G 專長助力下，打造全國首座 5G 智慧工廠，導入 5G 專網、人工智慧與物聯網應用於實際廠房。以下且看遠傳與台達如何達成 5G 智慧化產線，建構產能進化加速器。
| VIEW MORE »
### INSIDE Verizon Media DSP 擁有獨家的 Yahoo 電商數據，以及全台灣 1,500 萬以上的第一方會員數據，建立完整的 Cookieless 解決方案，幫助廣告主長期持續地掌握消費者輪廓並優化成效。
| VIEW MORE »
|  | ### INSIDE 微網紅媒合平台 Influenxio 圈圈科技發表 2021 上半年《 Instagram 微網紅行銷數據趨勢報告書》，提供品牌行銷作為參考。
| VIEW MORE »
### INSIDE 工研院：希望透過 Arm 全球生態系超過 1000 家技術合作夥伴的鏈結，逐步推動台灣成為亞太半導體生態系中心。
| VIEW MORE »
|  | ### INSIDE 某種程度上這已經是 Epic Games 的重大勝利，但距離完全勝利卻還有一大段距離，Apple 並沒被判定為「壟斷」。
| VIEW MORE »
### INSIDE CaaS國泰生態圈服務平台，如同一個金融服務的許願池，提供不同場景金融的服務需求，於此透過單一窗口以及專責營運團隊，線上線下一站解決。
| VIEW MORE »
|  | ### INSIDE 推特新開發測試的「機器人帳戶」功能，有種網路實名制的意味存在。
| VIEW MORE »
### INSIDE Nvidia 收購 ARM 遭到多方阻力，英國監管單位、歐盟決定針對併購案進行雙重調查，先前連特斯拉執行長馬斯克（Elon Musk）表示反對。
| VIEW MORE »
|  | ### INSIDE 喜馬拉雅 4 月提出美國 IPO 申請。
| VIEW MORE »